==> dnet-collector-plugins-1.3.22-20181104.134106-3-sources.jar: eu/dnetlib/data/collector/plugins/httpfilename/HttpWithFileNameCollectorIterator.java <==
package eu.dnetlib.data.collector.plugins.httpfilename;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.Iterator;
import java.util.NoSuchElementException;
import java.util.Objects;
import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.TimeUnit;

/**
 * Created by miriam on 25/06/2018.
 */
public class HttpWithFileNameCollectorIterator implements Iterator<String> {
    public static final String TERMINATOR = "FINITO";
    private static final Log log = LogFactory.getLog(HttpWithFileNameCollectorIterator.class);

     private final ArrayBlockingQueue<String> queue;

    public static final long waitTime = 60L;

    private String last = "<resource><DOI>JUNK</DOI></resource>";

    public HttpWithFileNameCollectorIterator(ArrayBlockingQueue<String> queue) {
        this.queue = queue;
        extractFromQueue();
    }

    @Override
        public boolean hasNext() {


            return !(Objects.equals(last, TERMINATOR) || Objects.equals(last,null));
        }

        @Override
        public String next() {
            try{

                return last;

            }finally{
                extractFromQueue();
            }

        }

    private void extractFromQueue() {
        try {
            last = queue.poll(waitTime, TimeUnit.SECONDS);
        }catch(InterruptedException e){
            log.warn(String.format("could not find elements to consume for more than %s%s", waitTime, TimeUnit.SECONDS));
            throw new NoSuchElementException(e.getMessage());
        }
    }


}

==> dnet-collector-plugins-1.3.22-20181107.172107-9-sources.jar: eu/dnetlib/data/collector/plugins/httpfilename/HttpWithFileNameCollectorIterator.java <==
package eu.dnetlib.data.collector.plugins.httpfilename;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.Iterator;
import java.util.NoSuchElementException;
import java.util.Objects;
import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.TimeUnit;

/**
 * Created by miriam on 25/06/2018.
 */
public class HttpWithFileNameCollectorIterator implements Iterator<String> {
    public static final String TERMINATOR = "FINITO";
    private static final Log log = LogFactory.getLog(HttpWithFileNameCollectorIterator.class);

     private final ArrayBlockingQueue<String> queue;

    public static final long waitTime = 60L;

    private String last = "<resource><DOI>JUNK</DOI></resource>";

    public HttpWithFileNameCollectorIterator(ArrayBlockingQueue<String> queue) {
        this.queue = queue;
        extractFromQueue();
    }

    @Override
        public boolean hasNext() {


            //return !(Objects.equals(last, TERMINATOR) || Objects.equals(last,null));
            return !(Objects.equals(last, TERMINATOR));
        }

        @Override
        public String next() {
            try{

                return last;

            }finally{
                extractFromQueue();
            }

        }

    private void extractFromQueue() {
       // try {
            while((last=queue.poll())==null);
            //last = queue.poll(waitTime, TimeUnit.SECONDS);
      /*  }catch(InterruptedException e){
            log.warn(String.format("could not find elements to consume for more than %s%s", waitTime, TimeUnit.SECONDS));
            throw new NoSuchElementException(e.getMessage());
        }*/
    }


}
